﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using Syncfusion.Pdf.Parsing;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.Storage.Streams;
using Windows.System;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Syncfusion.Windows.PdfViewer;
using Syncfusion.Pdf;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace PDFViewerWintRT
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
            this.DataContext = pdfViewer;
#if SyncfusionFramework4_5_1
            SwicthToThumbnailViewMode.Visibility = Visibility.Visible;
#endif
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {

        }

        private void PageLoaded(object sender, RoutedEventArgs e)
        {
            Assembly assembly = typeof(MainPage).GetTypeInfo().Assembly;
            Stream fileStream = assembly.GetManifestResourceStream("PDFViewerWintRT.Assets.Pdf.SpecBook.pdf");
            byte[] buffer = new byte[fileStream.Length];
            fileStream.Read(buffer, 0, buffer.Length);
            PdfLoadedDocument ldoc = new PdfLoadedDocument(buffer);
            
            pdfViewer.LoadDocument(ldoc);
        }

        async private void BtnOpen_Click_1(object sender, RoutedEventArgs e)
        {
            var picker = new FileOpenPicker();
            picker.SuggestedStartLocation = PickerLocationId.DocumentsLibrary;
            picker.ViewMode = PickerViewMode.List;
            picker.FileTypeFilter.Add(".pdf");
            var file = await picker.PickSingleFileAsync();
            if (file == null) return;
            var stream = await file.OpenAsync(Windows.Storage.FileAccessMode.Read);
            Stream fileStream = stream.AsStreamForRead();
            byte[] buffer = new byte[fileStream.Length];
            fileStream.Read(buffer, 0, buffer.Length);
            PdfLoadedDocument ldoc = new PdfLoadedDocument(buffer);
            pdfViewer.LoadDocument(ldoc);
        }

        private void GotoPopUpButton_Click(object sender, RoutedEventArgs e)
        {
            if (GotoPagePopUp.IsOpen)
            {
                GotoPagePopUp.IsOpen = false;
                PageDextTxtBox.Text = "Page Number";
                SolidColorBrush brush = new SolidColorBrush();
                brush.Color = Windows.UI.Colors.Gray;
                PageDextTxtBox.Foreground = brush;
            }
            else
            {
                GotoPagePopUp.IsOpen = true;
            }
        }

        private void PageDextTxtBox_KeyDown(object sender, KeyRoutedEventArgs e)
        {
            int destPage = 0;
            bool result = int.TryParse(PageDextTxtBox.Text, out destPage);
            if (e.Key == VirtualKey.Enter && result)
            {
                pdfViewer.GotoPage(destPage);
                PageDextTxtBox.Text = string.Empty;
            }
        }

        private void PageDextTxtBox_GotFocus(object sender, RoutedEventArgs e)
        {
            if (PageDextTxtBox.Text == "Page Number")
            {
                PageDextTxtBox.Text = string.Empty;
            }
            else
            {
                PageDextTxtBox.SelectAll();
            }
            SolidColorBrush brush = new SolidColorBrush();
            brush.Color = Windows.UI.Colors.Black;
            PageDextTxtBox.Foreground = brush;
        }

        private void ClosePopUp(object sender, TappedRoutedEventArgs e)
        {
            GotoPagePopUp.IsOpen = false;
            PageDextTxtBox.Text = "Page Number";
            SolidColorBrush brush = new SolidColorBrush();
            brush.Color = Windows.UI.Colors.Gray;
            PageDextTxtBox.Foreground = brush;
        }

        private void ViewModeCombo_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (pdfViewer != null)
            {
                string selectedViewMode = ((((sender as ListBox).SelectedItem as ListBoxItem).Content) as string);
                switch (selectedViewMode)
                {
                    case "Normal":
                        pdfViewer.ViewMode = Syncfusion.Windows.PdfViewer.PageViewMode.Normal;
                        break;
                    case "FitWidth":
                        pdfViewer.ViewMode = Syncfusion.Windows.PdfViewer.PageViewMode.FitWidth;
                        break;
                    case "OnePage":
                        pdfViewer.ViewMode = Syncfusion.Windows.PdfViewer.PageViewMode.OnePage;
                        break;
                }


                if (ViewModePopUp.IsOpen)
                {
                    ViewModePopUp.IsOpen = false;
                }
                else
                {
                    ViewModePopUp.IsOpen = true;
                }
            }
        }

        private void ViewModeGrid_Loaded(object sender, RoutedEventArgs e)
        {
            if (ViewModeCombo.Items.Count == 0)
            {
                ViewModeCombo.Items.Add(Syncfusion.Windows.PdfViewer.PageViewMode.FitWidth);
                ViewModeCombo.Items.Add(Syncfusion.Windows.PdfViewer.PageViewMode.Normal);
                ViewModeCombo.Items.Add(Syncfusion.Windows.PdfViewer.PageViewMode.OnePage);
            }
        }

        private void ViewModeSelected_Click(object sender, RoutedEventArgs e)
        {
            object selectedItem = ViewModeCombo.SelectedItem;
            if (selectedItem != null)
                pdfViewer.ViewMode = (Syncfusion.Windows.PdfViewer.PageViewMode)selectedItem;
        }

        private void ViewModePopUp_ButtonClick(object sender, RoutedEventArgs e)
        {

            if (ViewModePopUp.IsOpen)
            {
                ViewModePopUp.IsOpen = false;
            }
            else
            {
                ViewModePopUp.IsOpen = true;
            }
        }

        //Thumbnail View is specific to 8.1 version

        private void SwicthViewMode_Click(object sender, RoutedEventArgs e)
        {
#if SyncfusionFramework4_5_1
            pdfViewer.SwitchToThumbnailModeCommand.Execute(true);
#endif
        }
    }
}
